@@ -34,6 +34,16 @@
 #   Returns (invisibly) the path or pathname to the link.
 # }
 #
+# \section{Required privileges on Windows}{
+#   In order for \code{method="unix-symlink"} (utilizing
+#   \code{\link[base:files]{file.symlink}()}),
+#   \code{method="windows-ntfs-symlink"} (utilizing executable \code{mklink}),
+#   and/or \code{method="windows-shortcut"} (utilizing
+#   @see "createWindowsShortcut") to succeed on Windows,
+#   the client/R session must run with sufficient privileges
+#   (it has been reported that Administrative rights are necessary).
+# }
+#
 # @author
 #
 # \seealso{
@@ -76,9 +86,13 @@ setMethodS3("createLink", "default", function(link=".", target, skip=!overwrite,
   links <- c(link, sprintf("%s.LNK", link));
   if (any(file.exists(links))) {
     if (skip) {
-      warning("Link was not create. Link file already exists: ", link);
       res <- Arguments$getReadablePathname(link, mustExist=TRUE);
 
+      resA <- getAbsolutePath(Sys.readlink2(res))
+      if (!identical(resA, target)) {
+        warning(sprintf("Existing link (%s) was skipped, but it links to different target file than requested: %s != %s", sQuote(link), sQuote(resA), sQuote(target)));
+      }
+
       # If a Windows Shortcut, avoid returning the target.
       if (file.exists(links[2L]) && !file.exists(link)) {
         res <- link;
@@ -208,6 +222,13 @@ setMethodS3("createLink", "default", function(link=".", target, skip=!overwrite,
 
 ############################################################################
 # HISTORY:
+# 2014-04-26
+# o CLEANUP: createLink(..., skip=TRUE) no longer warns if the link file
+#   was skipped.  Now it only warns if the skipped link file links to a
+#   different file than the intended target file.
+# 2014-02-28
+# o DOCUMENTATION: Added an Rd section on privileges required on Windows
+#   for createLink() to work.
 # 2014-01-22
 # o CONSISTENCY: Now createLink(..., skip=TRUE) returns the Windows
 #   Shortcut link if it already exists (instead of the target as before).
